@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# coding=utf-8
 """
 =========
 Moar
@@ -15,27 +15,24 @@ See the documentation online at http://lucuma.github.com/moar/
 Features at a glance
 ---------------------
 
-* Pluggable engine support (PIL/Pillow and _Wand: http://docs.wand-py.org/ included).
+* Pluggable engine support (`Wand <http://docs.wand-py.org/>` included).
 * Automatic cache: a thumbnail is generated only once.
-* Pluggable storage support (FileSystem included).
+* Pluggable storage support (includes local files and S3 storages).
 * Flexible, simple syntax, generates no HTML.
 * Several filters available by default:
     * Cropping
     * Rotation
     * Blur
-    * Grayscale/Sepia
 * Easily extendable.
 
----------------------------------------
-_MIT License: http://www.opensource.org/licenses/mit-license.php
 
-© 2011 by _Lúcuma labs: http://lucumalabs.com
+:copyright: `Juan-Pablo Scaletti <http://jpscaletti.com>`_.
+:license: MIT, see LICENSE for more details.
 
 """
 from moar.thumbnailer import Thumbnailer
-from moar.engines.pil_engine import PILEngine
 from moar.engines.wand_engine import WandEngine
 from moar.storages.file_storage import FileStorage
+from moar.storages.s3_storage import S3Storage
 
-
-__version__ = '1.2.3'
+__version__ = '2.1.2'
