@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# coding=utf-8
 import moar
 import pytest
 
 
-@pytest.fixture(params=['PILEngine', 'WandEngine'])
+@pytest.fixture(params=['WandEngine'])
 def engine(request):
     return getattr(moar, request.param)()
