@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# coding=utf-8
 from os.path import join
 
 from moar import filters
@@ -24,6 +24,7 @@ def apply_filter(engine, fname, ini, out, *args, **kwargs):
     return tmp
 
 
+@pytest.mark.skip
 def test_blur(engine):
     if engine.name == 'wand':
         pytest.xfail("not implemented yet")
